==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Gnder");
define("_URL","URL");
define("_PRINTER","Yazdrlabilir Sayfa");
define("_FRIEND","Bu Haberi Arkadana Gnder");
define("_YOURNAME","sminiz");
define("_OK","Tamam!");
define("_RELATED","lgili Balantlar");
define("_MOREABOUT","Daha fazla");
define("_NEWSBY","Haber gnderen");
define("_MOSTREAD","En ok okunan haber:");
define("_READMORE","Devam...");
define("_BYTESMORE","byte kald");
define("_COMMENTSQ","yorumlar?");
define("_COMMENT","yorum");
define("_CONFIGURE","Dzenle");
define("_LOGINCREATE","Hesap A/Yarat");
define("_THRESHOLD","Balang");
define("_NOCOMMENTS","Yorum Yok");
define("_NESTED","-ie");
define("_FLAT","Dz");
define("_THREAD","Sral");
define("_OLDEST","Eski Baa");
define("_NEWEST","Yeni Baa");
define("_HIGHEST","Yksek Skorlar Baa");
define("_COMMENTSWARNING","Yorumlar yazarlarna aittir. eriklerinden biz sorumlu tutulamayz.");
define("_SCORE","Skor:");
define("_USERINFO","Kullanc Bilgisi");
define("_READREST","Bu yorumun devamn oku...");
define("_REPLY","Cevap Ver");
define("_REPLYMAIN","Yorum Ekle");
define("_NOSUBJECT","Konu Yok");
define("_NOANONCOMMENTS","Anonim kullanc yorum yazamaz, ltfen <a href=\"modules.php?name=Your_Account&op=new_user\">kayt olun</a>");
define("_PARENT","Yukar");
define("_ROOT","Kk");
define("_UCOMMENT","Yorum");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_POSTANON","Anonim Olarak Gnder");
define("_EXTRANS","HTML tag'leri metne");
define("_HTMLFORMATED","HTML Biimli");
define("_PLAINTEXT","Metin Biimli");
define("_ONN","stnde...");
define("_SUBJECT","Konu");
define("_COMMENTREPLY","Yorum Ekle");
define("_COMREPLYPRE","Yorum nizleme");
define("_NOTRIGHT","Bu fonksiyona deer geirilirken sorun olutu. Bu mesaj sadece ilerin yoldan kmasn engellemek iindir");
define("_SENDAMSG","Mesaj Gnder");
define("_YOUSENDSTORY","Bu haberi:");
define("_TOAFRIEND","arkadanza gndereceksiniz:");
define("_FYOURNAME","sminiz:");
define("_FYOUREMAIL","E-mail Adresiniz:");
define("_FFRIENDNAME","Arkadanzn smi:");
define("_FFRIENDEMAIL","Arkadanzn E-mail'i:");
define("_INTERESTING","ilginc bir haber:");
define("_HELLO","Merhaba");
define("_YOURFRIEND","Arkadasiniz");
define("_CONSIDERED","asagidaki haberi ilginc buldu ve size gondermek istedi.");
define("_FDATE","Tarih:");
define("_FTOPIC","Konu:");
define("_YOUCANREAD","Daha fazla haber icin:");
define("_FSTORY","Haber");
define("_HASSENT","Gnderildi:");
define("_THANKS","Teekkrler!");
define("_RECOMMEND","Bu Siteyi Arkadana ner");
define("_PDATE","Tarih:");
define("_PTOPIC","Konu:");
define("_COMESFROM","Bu haberin geldigi yer:");
define("_THEURL","Bu haber icin adres:");
define("_PREVIEW","nizleme");
define("_NEWUSER","Yeni Kullanc");
define("_OPTIONS","Seenekler");
define("_REFRESH","Yenile");
define("_ADD","Ekle");
define("_NOCOMMENTSACT","zgnm, bu yaz iin yorumlar aktif deil.");
define("_ARTICLEPOLL","Yaznn Anketi");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Gnder");
define("_URL","URL");
define("_PRINTER","Yazdrlabilir Sayfa");
define("_FRIEND","Bu Haberi Arkadana Gnder");
define("_YOURNAME","sminiz");
define("_OK","Tamam!");
define("_RELATED","lgili Balantlar");
define("_MOREABOUT","Daha fazla");
define("_NEWSBY","Haber gnderen");
define("_MOSTREAD","En ok okunan haber:");
define("_READMORE","Devam...");
define("_BYTESMORE","byte kald");
define("_COMMENTSQ","yorumlar?");
define("_COMMENT","yorum");
define("_CONFIGURE","Dzenle");
define("_LOGINCREATE","Hesap A/Yarat");
define("_THRESHOLD","Balang");
define("_NOCOMMENTS","Yorum Yok");
define("_NESTED","-ie");
define("_FLAT","Dz");
define("_THREAD","Sral");
define("_OLDEST","Eski Baa");
define("_NEWEST","Yeni Baa");
define("_HIGHEST","Yksek Skorlar Baa");
define("_COMMENTSWARNING","Yorumlar yazarlarna aittir. eriklerinden biz sorumlu tutulamayz.");
define("_SCORE","Skor:");
define("_USERINFO","Kullanc Bilgisi");
define("_READREST","Bu yorumun devamn oku...");
define("_REPLY","Cevap Ver");
define("_REPLYMAIN","Yorum Ekle");
define("_NOSUBJECT","Konu Yok");
define("_NOANONCOMMENTS","Anonim kullanc yorum yazamaz, ltfen <a href=\"modules.php?name=Your_Account&op=new_user\">kayt olun</a>");
define("_PARENT","Yukar");
define("_ROOT","Kk");
define("_UCOMMENT","Yorum");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_POSTANON","Anonim Olarak Gnder");
define("_EXTRANS","HTML tag'leri metne");
define("_HTMLFORMATED","HTML Biimli");
define("_PLAINTEXT","Metin Biimli");
define("_ONN","stnde...");
define("_SUBJECT","Konu");
define("_COMMENTREPLY","Yorum Ekle");
define("_COMREPLYPRE","Yorum nizleme");
define("_NOTRIGHT","Bu fonksiyona deer geirilirken sorun olutu. Bu mesaj sadece ilerin yoldan kmasn engellemek iindir");
define("_SENDAMSG","Mesaj Gnder");
define("_YOUSENDSTORY","Bu haberi:");
define("_TOAFRIEND","arkadanza gndereceksiniz:");
define("_FYOURNAME","sminiz:");
define("_FYOUREMAIL","E-mail Adresiniz:");
define("_FFRIENDNAME","Arkadanzn smi:");
define("_FFRIENDEMAIL","Arkadanzn E-mail'i:");
define("_INTERESTING","ilginc bir haber:");
define("_HELLO","Merhaba");
define("_YOURFRIEND","Arkadasiniz");
define("_CONSIDERED","asagidaki haberi ilginc buldu ve size gondermek istedi.");
define("_FDATE","Tarih:");
define("_FTOPIC","Konu:");
define("_YOUCANREAD","Daha fazla haber icin:");
define("_FSTORY","Haber");
define("_HASSENT","Gnderildi:");
define("_THANKS","Teekkrler!");
define("_RECOMMEND","Bu Siteyi Arkadana ner");
define("_PDATE","Tarih:");
define("_PTOPIC","Konu:");
define("_COMESFROM","Bu haberin geldigi yer:");
define("_THEURL","Bu haber icin adres:");
define("_PREVIEW","nizleme");
define("_NEWUSER","Yeni Kullanc");
define("_OPTIONS","Seenekler");
define("_REFRESH","Yenile");
define("_ADD","Ekle");
define("_NOCOMMENTSACT","zgnm, bu yaz iin yorumlar aktif deil.");
define("_ARTICLEPOLL","Yaznn Anketi");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
